"""Collection of reinforcement learning algorithms."""

from .trainer import Trainer
from .trainer import with_common_config
